@@ -9,6 +9,7 @@ from ..utils import (
     _configuration_args,
     encodeFilename,
     PostProcessingError,
+    write_string,
 )
 
 
@@ -74,6 +75,11 @@ class PostProcessor(metaclass=PostProcessorMetaClass):
         if self._downloader:
             return self._downloader.report_warning(text, *args, **kwargs)
 
+    def deprecation_warning(self, text):
+        if self._downloader:
+            return self._downloader.deprecation_warning(text)
+        write_string(f'DeprecationWarning: {text}')
+
     def report_error(self, text, *args, **kwargs):
         # Exists only for compatibility. Do not use
         if self._downloader:
